@@ -1,5 +1,5 @@
-from .__dependencies__ import json_fix
-from .__dependencies__ import file_system_py as FS
+from .dependencies import json_fix
+from .dependencies import file_system_py as FS
 
 from time import time as now
 from random import shuffle
